# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/deployed_model.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/deployed_model.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgateway/deployed_model.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x86\x05\n\rDeployedModel\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\r\n\x05model\x18\x06 \x01(\t\x12\x12\n\ndeployment\x18\x07 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x08 \x01(\x08\x12\x32\n\x05state\x18\t \x01(\x0e\x32\x1c.gateway.DeployedModel.StateB\x05\xe2\x41\x02\x03\x05\x12\x12\n\nserverless\x18\n \x01(\x08\x12&\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x0e\n\x06public\x18\x0c \x01(\x08\x12\x35\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"`\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bUNDEPLOYING\x10\x01\x12\r\n\tDEPLOYING\x10\x02\x12\x0c\n\x08\x44\x45PLOYED\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\"\x04\x08\x05\x10\x05:\x88\x01\xea\x41v\n\x1e\x61pi.fireworks.ai/DeployedModel\x12\x35\x61\x63\x63ounts/{AccountId}/deployedModels/{DeployedModelId}*\x0e\x64\x65ployedModels2\rdeployedModel\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"\xa1\x01\n\x10\x44\x65ployedModelRef\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x18\n\ndeployment\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03\x12\x31\n\x05state\x18\x03 \x01(\x0e\x32\x1c.gateway.DeployedModel.StateB\x04\xe2\x41\x01\x03\x12\x15\n\x07\x64\x65\x66\x61ult\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x03\x12\x14\n\x06public\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x03\"h\n\x1a\x43reateDeployedModelRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\x0e\x64\x65ployed_model\x18\x02 \x01(\x0b\x32\x16.gateway.DeployedModelB\x04\xe2\x41\x01\x02\"0\n\x1a\x44\x65leteDeployedModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"-\n\x17GetDeployedModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x92\x01\n\x19ListDeployedModelsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"z\n\x1aListDeployedModelsResponse\x12/\n\x0f\x64\x65ployed_models\x18\x01 \x03(\x0b\x32\x16.gateway.DeployedModel\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x89\x01\n\x1aUpdateDeployedModelRequest\x12\x34\n\x0e\x64\x65ployed_model\x18\x01 \x01(\x0b\x32\x16.gateway.DeployedModelB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.deployed_model_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_DEPLOYEDMODEL'].fields_by_name['name']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODEL'].fields_by_name['display_name']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYEDMODEL'].fields_by_name['description']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYEDMODEL'].fields_by_name['create_time']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODEL'].fields_by_name['created_by']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODEL'].fields_by_name['state']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODEL'].fields_by_name['status']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODEL'].fields_by_name['update_time']._loaded_options = None
  _globals['_DEPLOYEDMODEL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYEDMODEL']._loaded_options = None
  _globals['_DEPLOYEDMODEL']._serialized_options = b'\352Av\n\036api.fireworks.ai/DeployedModel\0225accounts/{AccountId}/deployedModels/{DeployedModelId}*\016deployedModels2\rdeployedModel\202\361\004\013\n\007Account\030\001'
  _globals['_DEPLOYEDMODELREF'].fields_by_name['name']._loaded_options = None
  _globals['_DEPLOYEDMODELREF'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_DEPLOYEDMODELREF'].fields_by_name['deployment']._loaded_options = None
  _globals['_DEPLOYEDMODELREF'].fields_by_name['deployment']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYEDMODELREF'].fields_by_name['state']._loaded_options = None
  _globals['_DEPLOYEDMODELREF'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYEDMODELREF'].fields_by_name['default']._loaded_options = None
  _globals['_DEPLOYEDMODELREF'].fields_by_name['default']._serialized_options = b'\342A\001\003'
  _globals['_DEPLOYEDMODELREF'].fields_by_name['public']._loaded_options = None
  _globals['_DEPLOYEDMODELREF'].fields_by_name['public']._serialized_options = b'\342A\001\003'
  _globals['_CREATEDEPLOYEDMODELREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEDEPLOYEDMODELREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEDEPLOYEDMODELREQUEST'].fields_by_name['deployed_model']._loaded_options = None
  _globals['_CREATEDEPLOYEDMODELREQUEST'].fields_by_name['deployed_model']._serialized_options = b'\342A\001\002'
  _globals['_DELETEDEPLOYEDMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEDEPLOYEDMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETDEPLOYEDMODELREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETDEPLOYEDMODELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDEPLOYEDMODELSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEDEPLOYEDMODELREQUEST'].fields_by_name['deployed_model']._loaded_options = None
  _globals['_UPDATEDEPLOYEDMODELREQUEST'].fields_by_name['deployed_model']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEDEPLOYEDMODELREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEDEPLOYEDMODELREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DEPLOYEDMODEL']._serialized_start=214
  _globals['_DEPLOYEDMODEL']._serialized_end=860
  _globals['_DEPLOYEDMODEL_STATE']._serialized_start=625
  _globals['_DEPLOYEDMODEL_STATE']._serialized_end=721
  _globals['_DEPLOYEDMODELREF']._serialized_start=863
  _globals['_DEPLOYEDMODELREF']._serialized_end=1024
  _globals['_CREATEDEPLOYEDMODELREQUEST']._serialized_start=1026
  _globals['_CREATEDEPLOYEDMODELREQUEST']._serialized_end=1130
  _globals['_DELETEDEPLOYEDMODELREQUEST']._serialized_start=1132
  _globals['_DELETEDEPLOYEDMODELREQUEST']._serialized_end=1180
  _globals['_GETDEPLOYEDMODELREQUEST']._serialized_start=1182
  _globals['_GETDEPLOYEDMODELREQUEST']._serialized_end=1227
  _globals['_LISTDEPLOYEDMODELSREQUEST']._serialized_start=1230
  _globals['_LISTDEPLOYEDMODELSREQUEST']._serialized_end=1376
  _globals['_LISTDEPLOYEDMODELSRESPONSE']._serialized_start=1378
  _globals['_LISTDEPLOYEDMODELSRESPONSE']._serialized_end=1500
  _globals['_UPDATEDEPLOYEDMODELREQUEST']._serialized_start=1503
  _globals['_UPDATEDEPLOYEDMODELREQUEST']._serialized_end=1640
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/billing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/billing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..google.type import money_pb2 as google_dot_type_dot_money__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/billing.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/type/money.proto\"\'\n\x11GetBalanceRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\",\n\x07\x42\x61lance\x12!\n\x05money\x18\x01 \x01(\x0b\x32\x12.google.type.Money\"1\n\x19ListPaymentMethodsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\xf7\x01\n\x15StripeCheckoutSession\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x63heckout_url\x18\x02 \x01(\t\x12\x31\n\x04mode\x18\x03 \x01(\x0e\x32#.gateway.StripeCheckoutSession.Mode\x12\"\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x12.google.type.Money\x12/\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PAYMENT\x10\x01\x12\t\n\x05SETUP\x10\x02\"\x9e\x04\n\x1aListPaymentMethodsResponse\x12!\n\x19\x64\x65\x66\x61ult_payment_method_id\x18\x01 \x01(\t\x12W\n\x16stripe_payment_methods\x18\x02 \x03(\x0b\x32\x37.gateway.ListPaymentMethodsResponse.StripePaymentMethod\x12R\n\x19pending_checkout_sessions\x18\x03 \x03(\x0b\x32\x1e.gateway.StripeCheckoutSessionB\x0f\xfa\xd2\xe4\x93\x02\t\x12\x07UI_ONLY\x1aI\n\x04\x43\x61rd\x12\r\n\x05\x62rand\x18\x01 \x01(\t\x12\r\n\x05last4\x18\x02 \x01(\t\x12\x11\n\texp_month\x18\x03 \x01(\x05\x12\x10\n\x08\x65xp_year\x18\x04 \x01(\x05\x1a\x31\n\rUsBankAccount\x12\x11\n\tbank_name\x18\x01 \x01(\t\x12\r\n\x05last4\x18\x02 \x01(\t\x1a\xb1\x01\n\x13StripePaymentMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x38\n\x04\x63\x61rd\x18\x02 \x01(\x0b\x32(.gateway.ListPaymentMethodsResponse.CardH\x00\x12L\n\x0fus_bank_account\x18\x03 \x01(\x0b\x32\x31.gateway.ListPaymentMethodsResponse.UsBankAccountH\x00\x42\x06\n\x04type\"\xa6\x01\n\x10ListCostsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x02\x12\x12\n\ncumulative\x18\x04 \x01(\x08\"\x8d\x02\n\x11ListCostsResponse\x12@\n\x0f\x63ost_data_items\x18\x01 \x03(\x0b\x32\'.gateway.ListCostsResponse.CostDataItem\x1a\xb5\x01\n\x0c\x43ostDataItem\x12$\n\x08subtotal\x18\x01 \x01(\x0b\x32\x12.google.type.Money\x12!\n\x05total\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9d\x01\n\x13ListInvoicesRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x0f\n\x07pending\x18\x02 \x01(\x08\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\"\xb0\x02\n\x07Invoice\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\namount_due\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12\x13\n\x0binvoice_url\x18\x03 \x01(\t\x12%\n\x05state\x18\x04 \x01(\x0e\x32\x16.gateway.Invoice.State\x12/\n\x0btarget_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpaid_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06ISSUED\x10\x02\x12\x08\n\x04PAID\x10\x03\x12\x08\n\x04VOID\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"g\n\x14ListInvoicesResponse\x12\"\n\x08invoices\x18\x01 \x03(\x0b\x32\x10.gateway.Invoice\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"H\n\x07SKUInfo\x12\x0b\n\x03sku\x18\x01 \x01(\t\x12\"\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12\x0c\n\x04unit\x18\x03 \x01(\t\"\x9b\x01\n\x1b\x45xportBillingMetricsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\"3\n\x1c\x45xportBillingMetricsResponse\x12\x13\n\x0bsigned_urls\x18\x01 \x03(\t\"4\n\x1eGetTotalHistoricalSpendRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"D\n\x1fGetTotalHistoricalSpendResponse\x12!\n\x05spend\x18\x01 \x01(\x0b\x32\x12.google.type.Money\"U\n\"ListHuggingFaceBillingCostsRecords\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0brequest_ids\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"E\n\x18\x42illingRequestCostRecord\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x15\n\rcost_nano_usd\x18\x02 \x01(\x01\"Z\n#ListHuggingFaceBillingCostsResponse\x12\x33\n\x08requests\x18\x01 \x03(\x0b\x32!.gateway.BillingRequestCostRecordBCZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.billing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_GETBALANCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETBALANCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTPAYMENTMETHODSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPAYMENTMETHODSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPAYMENTMETHODSRESPONSE'].fields_by_name['pending_checkout_sessions']._loaded_options = None
  _globals['_LISTPAYMENTMETHODSRESPONSE'].fields_by_name['pending_checkout_sessions']._serialized_options = b'\372\322\344\223\002\t\022\007UI_ONLY'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\002'
  _globals['_LISTCOSTSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_LISTCOSTSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\002'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTINVOICESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTINVOICESREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['start_time']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['start_time']._serialized_options = b'\342A\001\001'
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['end_time']._loaded_options = None
  _globals['_EXPORTBILLINGMETRICSREQUEST'].fields_by_name['end_time']._serialized_options = b'\342A\001\001'
  _globals['_GETTOTALHISTORICALSPENDREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTOTALHISTORICALSPENDREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['request_ids']._loaded_options = None
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS'].fields_by_name['request_ids']._serialized_options = b'\342A\001\002'
  _globals['_GETBALANCEREQUEST']._serialized_start=154
  _globals['_GETBALANCEREQUEST']._serialized_end=193
  _globals['_BALANCE']._serialized_start=195
  _globals['_BALANCE']._serialized_end=239
  _globals['_LISTPAYMENTMETHODSREQUEST']._serialized_start=241
  _globals['_LISTPAYMENTMETHODSREQUEST']._serialized_end=290
  _globals['_STRIPECHECKOUTSESSION']._serialized_start=293
  _globals['_STRIPECHECKOUTSESSION']._serialized_end=540
  _globals['_STRIPECHECKOUTSESSION_MODE']._serialized_start=488
  _globals['_STRIPECHECKOUTSESSION_MODE']._serialized_end=540
  _globals['_LISTPAYMENTMETHODSRESPONSE']._serialized_start=543
  _globals['_LISTPAYMENTMETHODSRESPONSE']._serialized_end=1085
  _globals['_LISTPAYMENTMETHODSRESPONSE_CARD']._serialized_start=781
  _globals['_LISTPAYMENTMETHODSRESPONSE_CARD']._serialized_end=854
  _globals['_LISTPAYMENTMETHODSRESPONSE_USBANKACCOUNT']._serialized_start=856
  _globals['_LISTPAYMENTMETHODSRESPONSE_USBANKACCOUNT']._serialized_end=905
  _globals['_LISTPAYMENTMETHODSRESPONSE_STRIPEPAYMENTMETHOD']._serialized_start=908
  _globals['_LISTPAYMENTMETHODSRESPONSE_STRIPEPAYMENTMETHOD']._serialized_end=1085
  _globals['_LISTCOSTSREQUEST']._serialized_start=1088
  _globals['_LISTCOSTSREQUEST']._serialized_end=1254
  _globals['_LISTCOSTSRESPONSE']._serialized_start=1257
  _globals['_LISTCOSTSRESPONSE']._serialized_end=1526
  _globals['_LISTCOSTSRESPONSE_COSTDATAITEM']._serialized_start=1345
  _globals['_LISTCOSTSRESPONSE_COSTDATAITEM']._serialized_end=1526
  _globals['_LISTINVOICESREQUEST']._serialized_start=1529
  _globals['_LISTINVOICESREQUEST']._serialized_end=1686
  _globals['_INVOICE']._serialized_start=1689
  _globals['_INVOICE']._serialized_end=1993
  _globals['_INVOICE_STATE']._serialized_start=1908
  _globals['_INVOICE_STATE']._serialized_end=1993
  _globals['_LISTINVOICESRESPONSE']._serialized_start=1995
  _globals['_LISTINVOICESRESPONSE']._serialized_end=2098
  _globals['_SKUINFO']._serialized_start=2100
  _globals['_SKUINFO']._serialized_end=2172
  _globals['_EXPORTBILLINGMETRICSREQUEST']._serialized_start=2175
  _globals['_EXPORTBILLINGMETRICSREQUEST']._serialized_end=2330
  _globals['_EXPORTBILLINGMETRICSRESPONSE']._serialized_start=2332
  _globals['_EXPORTBILLINGMETRICSRESPONSE']._serialized_end=2383
  _globals['_GETTOTALHISTORICALSPENDREQUEST']._serialized_start=2385
  _globals['_GETTOTALHISTORICALSPENDREQUEST']._serialized_end=2437
  _globals['_GETTOTALHISTORICALSPENDRESPONSE']._serialized_start=2439
  _globals['_GETTOTALHISTORICALSPENDRESPONSE']._serialized_end=2507
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS']._serialized_start=2509
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRECORDS']._serialized_end=2594
  _globals['_BILLINGREQUESTCOSTRECORD']._serialized_start=2596
  _globals['_BILLINGREQUESTCOSTRECORD']._serialized_end=2665
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRESPONSE']._serialized_start=2667
  _globals['_LISTHUGGINGFACEBILLINGCOSTSRESPONSE']._serialized_end=2757
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/node_pool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/node_pool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/node_pool.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8e\x0b\n\x08NodePool\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x0b\xe2\x41\x01\x01\xbaH\x04r\x02\x18?\x12\x36\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12&\n\x0emin_node_count\x18\n \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\x12&\n\x0emax_node_count\x18\x0b \x01(\x05\x42\x0e\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\x12-\n\x18overprovision_node_count\x18\x0c \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12-\n\reks_node_pool\x18\x07 \x01(\x0b\x32\x14.gateway.EksNodePoolH\x00\x12/\n\x0e\x66\x61ke_node_pool\x18\x03 \x01(\x0b\x32\x15.gateway.FakeNodePoolH\x00\x12=\n\x0b\x61nnotations\x18\x0e \x03(\x0b\x32\".gateway.NodePool.AnnotationsEntryB\x04\xe2\x41\x01\x01\x12-\n\x05state\x18\x05 \x01(\x0e\x32\x17.gateway.NodePool.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12:\n\x0fnode_pool_stats\x18\r \x01(\x0b\x32\x16.gateway.NodePoolStatsB\t\xe2\x41\x02\x03\x05\xa0\xf1\x04\x01\x12\x35\n\x0bupdate_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04:\x90\x05\xea\x41r\n\x19\x61pi.fireworks.ai/NodePool\x12@accounts/{AccountId}/clusters/{ClusterId}/nodePools/{NodePoolId}*\tnodePools2\x08nodePool\xbaH\x8a\x04\x1a\xa6\x01\n\x1anode_pool.node_count_check\x12>max_node_count must be greater than or equal to min_node_count\x1aHthis.max_node_count == 0 || (this.max_node_count >= this.min_node_count)\x1a\xc2\x01\n*node_pool.overprovision_node_count_range_1\x12Hoverprovision_node_count cannot exceed (max_node_count - min_node_count)\x1aJthis.overprovision_node_count <= this.max_node_count - this.min_node_count\x1a\x99\x01\n*node_pool.overprovision_node_count_range_2\x12\x35overprovision_node_count cannot exceed min_node_count\x1a\x34this.overprovision_node_count <= this.min_node_count\x82\xf1\x04\t\n\x07\x43lusterB\x10\n\x0enode_pool_type\"\xea\x01\n\x0b\x45ksNodePool\x12\x18\n\tnode_role\x18\x01 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1c\n\rinstance_type\x18\x02 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x13\n\x04spot\x18\x04 \x01(\x08\x42\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0fnode_group_name\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x19\n\nsubnet_ids\x18\x06 \x03(\tB\x05\xe2\x41\x02\x01\x05\x12\x13\n\x04zone\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0fplacement_group\x18\x08 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x1e\n\x0flaunch_template\x18\t \x01(\tB\x05\xe2\x41\x02\x01\x05\"P\n\x0c\x46\x61keNodePool\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x11\n\tnum_nodes\x18\x02 \x01(\x05\x12\x17\n\x0fservice_account\x18\x03 \x01(\t\"\xe5\x02\n\rNodePoolStats\x12\x12\n\nnode_count\x18\x01 \x01(\x05\x12\x16\n\x0eranks_per_node\x18\x02 \x01(\x05\x12\x19\n\x11\x65nvironment_count\x18\x03 \x01(\x05\x12\x19\n\x11\x65nvironment_ranks\x18\x04 \x01(\x05\x12\x42\n\x0f\x62\x61tch_job_count\x18\x05 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobCountEntry\x12\x42\n\x0f\x62\x61tch_job_ranks\x18\x06 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobRanksEntry\x1a\x34\n\x12\x42\x61tchJobCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12\x42\x61tchJobRanksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"u\n\x15\x43reateNodePoolRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12*\n\tnode_pool\x18\x02 \x01(\x0b\x32\x11.gateway.NodePoolB\x04\xe2\x41\x01\x02\x12\x1a\n\x0cnode_pool_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"(\n\x12GetNodePoolRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x8d\x01\n\x14ListNodePoolsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"k\n\x15ListNodePoolsResponse\x12%\n\nnode_pools\x18\x01 \x03(\x0b\x32\x11.gateway.NodePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"z\n\x15UpdateNodePoolRequest\x12*\n\tnode_pool\x18\x01 \x01(\x0b\x32\x11.gateway.NodePoolB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"+\n\x15\x44\x65leteNodePoolRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"H\n\x1b\x42\x61tchDeleteNodePoolsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"-\n\x17GetNodePoolStatsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.node_pool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_NODEPOOL'].fields_by_name['name']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['display_name']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001\272H\004r\002\030?'
  _globals['_NODEPOOL'].fields_by_name['create_time']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['min_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['min_node_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000'
  _globals['_NODEPOOL'].fields_by_name['max_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['max_node_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000'
  _globals['_NODEPOOL'].fields_by_name['overprovision_node_count']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['overprovision_node_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_NODEPOOL'].fields_by_name['annotations']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_NODEPOOL'].fields_by_name['state']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['status']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_NODEPOOL'].fields_by_name['node_pool_stats']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['node_pool_stats']._serialized_options = b'\342A\002\003\005\240\361\004\001'
  _globals['_NODEPOOL'].fields_by_name['update_time']._loaded_options = None
  _globals['_NODEPOOL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_NODEPOOL']._loaded_options = None
  _globals['_NODEPOOL']._serialized_options = b'\352Ar\n\031api.fireworks.ai/NodePool\022@accounts/{AccountId}/clusters/{ClusterId}/nodePools/{NodePoolId}*\tnodePools2\010nodePool\272H\212\004\032\246\001\n\032node_pool.node_count_check\022>max_node_count must be greater than or equal to min_node_count\032Hthis.max_node_count == 0 || (this.max_node_count >= this.min_node_count)\032\302\001\n*node_pool.overprovision_node_count_range_1\022Hoverprovision_node_count cannot exceed (max_node_count - min_node_count)\032Jthis.overprovision_node_count <= this.max_node_count - this.min_node_count\032\231\001\n*node_pool.overprovision_node_count_range_2\0225overprovision_node_count cannot exceed min_node_count\0324this.overprovision_node_count <= this.min_node_count\202\361\004\t\n\007Cluster'
  _globals['_EKSNODEPOOL'].fields_by_name['node_role']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['node_role']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['instance_type']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['instance_type']._serialized_options = b'\342A\002\002\005'
  _globals['_EKSNODEPOOL'].fields_by_name['spot']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['spot']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['node_group_name']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['node_group_name']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['subnet_ids']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['zone']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['zone']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['placement_group']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['placement_group']._serialized_options = b'\342A\002\001\005'
  _globals['_EKSNODEPOOL'].fields_by_name['launch_template']._loaded_options = None
  _globals['_EKSNODEPOOL'].fields_by_name['launch_template']._serialized_options = b'\342A\002\001\005'
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._loaded_options = None
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_options = b'8\001'
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._loaded_options = None
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool']._serialized_options = b'\342A\001\002'
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_CREATENODEPOOLREQUEST'].fields_by_name['node_pool_id']._serialized_options = b'\342A\001\002'
  _globals['_GETNODEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETNODEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTNODEPOOLSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['node_pool']._loaded_options = None
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['node_pool']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATENODEPOOLREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETENODEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETENODEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETENODEPOOLSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_GETNODEPOOLSTATSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETNODEPOOLSTATSREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_NODEPOOL']._serialized_start=238
  _globals['_NODEPOOL']._serialized_end=1660
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_start=850
  _globals['_NODEPOOL_ANNOTATIONSENTRY']._serialized_end=900
  _globals['_NODEPOOL_STATE']._serialized_start=902
  _globals['_NODEPOOL_STATE']._serialized_end=983
  _globals['_EKSNODEPOOL']._serialized_start=1663
  _globals['_EKSNODEPOOL']._serialized_end=1897
  _globals['_FAKENODEPOOL']._serialized_start=1899
  _globals['_FAKENODEPOOL']._serialized_end=1979
  _globals['_NODEPOOLSTATS']._serialized_start=1982
  _globals['_NODEPOOLSTATS']._serialized_end=2339
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_start=2233
  _globals['_NODEPOOLSTATS_BATCHJOBCOUNTENTRY']._serialized_end=2285
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_start=2287
  _globals['_NODEPOOLSTATS_BATCHJOBRANKSENTRY']._serialized_end=2339
  _globals['_CREATENODEPOOLREQUEST']._serialized_start=2341
  _globals['_CREATENODEPOOLREQUEST']._serialized_end=2458
  _globals['_GETNODEPOOLREQUEST']._serialized_start=2460
  _globals['_GETNODEPOOLREQUEST']._serialized_end=2500
  _globals['_LISTNODEPOOLSREQUEST']._serialized_start=2503
  _globals['_LISTNODEPOOLSREQUEST']._serialized_end=2644
  _globals['_LISTNODEPOOLSRESPONSE']._serialized_start=2646
  _globals['_LISTNODEPOOLSRESPONSE']._serialized_end=2753
  _globals['_UPDATENODEPOOLREQUEST']._serialized_start=2755
  _globals['_UPDATENODEPOOLREQUEST']._serialized_end=2877
  _globals['_DELETENODEPOOLREQUEST']._serialized_start=2879
  _globals['_DELETENODEPOOLREQUEST']._serialized_end=2922
  _globals['_BATCHDELETENODEPOOLSREQUEST']._serialized_start=2924
  _globals['_BATCHDELETENODEPOOLSREQUEST']._serialized_end=2996
  _globals['_GETNODEPOOLSTATSREQUEST']._serialized_start=2998
  _globals['_GETNODEPOOLSTATSREQUEST']._serialized_end=3043
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/user.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12gateway/user.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x04User\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x11\n\x04role\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\x05\x65mail\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\"`\n\x11\x43reateUserRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x04user\x18\x02 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\x12\x14\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"#\n\x0eGetUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x84\x01\n\x10ListUsersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"^\n\x11ListUsersResponse\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.gateway.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"5\n\x11UpdateUserRequest\x12 \n\x04user\x18\x01 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\"&\n\x11\x44\x65leteUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_USER = _descriptor.Descriptor(
  name='User',
  full_name='gateway.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.User.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.User.display_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.User.create_time', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.User.role', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='gateway.User.email', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=252,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='gateway.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateUserRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='gateway.CreateUserRequest.user', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='gateway.CreateUserRequest.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=350,
)


_GETUSERREQUEST = _descriptor.Descriptor(
  name='GetUserRequest',
  full_name='gateway.GetUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetUserRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=387,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='gateway.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListUsersRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListUsersRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListUsersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListUsersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListUsersRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=522,
)


_LISTUSERSRESPONSE = _descriptor.Descriptor(
  name='ListUsersResponse',
  full_name='gateway.ListUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='gateway.ListUsersResponse.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListUsersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListUsersResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=524,
  serialized_end=618,
)


_UPDATEUSERREQUEST = _descriptor.Descriptor(
  name='UpdateUserRequest',
  full_name='gateway.UpdateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='gateway.UpdateUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=673,
)


_DELETEUSERREQUEST = _descriptor.Descriptor(
  name='DeleteUserRequest',
  full_name='gateway.DeleteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteUserRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=713,
)

_USER.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEUSERREQUEST.fields_by_name['user'].message_type = _USER
_LISTUSERSRESPONSE.fields_by_name['users'].message_type = _USER
_UPDATEUSERREQUEST.fields_by_name['user'].message_type = _USER
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['GetUserRequest'] = _GETUSERREQUEST
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserRequest'] = _UPDATEUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserRequest'] = _DELETEUSERREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.User)
  })
_sym_db.RegisterMessage(User)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

GetUserRequest = _reflection.GeneratedProtocolMessageType('GetUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQUEST,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetUserRequest)
  })
_sym_db.RegisterMessage(GetUserRequest)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType('ListUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSRESPONSE,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListUsersResponse)
  })
_sym_db.RegisterMessage(ListUsersResponse)

UpdateUserRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERREQUEST,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateUserRequest)
  })
_sym_db.RegisterMessage(UpdateUserRequest)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'gateway.user_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)


DESCRIPTOR._options = None
_USER.fields_by_name['name']._options = None
_USER.fields_by_name['display_name']._options = None
_USER.fields_by_name['create_time']._options = None
_USER.fields_by_name['role']._options = None
_USER.fields_by_name['email']._options = None
_CREATEUSERREQUEST.fields_by_name['parent']._options = None
_CREATEUSERREQUEST.fields_by_name['user']._options = None
_CREATEUSERREQUEST.fields_by_name['user_id']._options = None
_GETUSERREQUEST.fields_by_name['name']._options = None
_LISTUSERSREQUEST.fields_by_name['parent']._options = None
_LISTUSERSREQUEST.fields_by_name['page_size']._options = None
_LISTUSERSREQUEST.fields_by_name['page_token']._options = None
_LISTUSERSREQUEST.fields_by_name['filter']._options = None
_LISTUSERSREQUEST.fields_by_name['order_by']._options = None
_UPDATEUSERREQUEST.fields_by_name['user']._options = None
_DELETEUSERREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



from ..buf.validate import validate_pb2 as _validate_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Evaluation(_message.Message):
    __slots__ = ("name", "create_time", "created_by", "status", "evaluation_type", "description", "providers", "assertions", "update_time")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    ASSERTIONS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    create_time: _timestamp_pb2.Timestamp
    created_by: str
    status: _status_pb2.Status
    evaluation_type: str
    description: str
    providers: _containers.RepeatedCompositeFieldContainer[Provider]
    assertions: _containers.RepeatedCompositeFieldContainer[Assertion]
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., evaluation_type: _Optional[str] = ..., description: _Optional[str] = ..., providers: _Optional[_Iterable[_Union[Provider, _Mapping]]] = ..., assertions: _Optional[_Iterable[_Union[Assertion, _Mapping]]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Assertion(_message.Message):
    __slots__ = ("assertion_type", "llm_assertion", "code_assertion", "metric_name")
    class AssertionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ASSERTION_TYPE_UNSPECIFIED: _ClassVar[Assertion.AssertionType]
        ASSERTION_TYPE_LLM: _ClassVar[Assertion.AssertionType]
        ASSERTION_TYPE_CODE: _ClassVar[Assertion.AssertionType]
    ASSERTION_TYPE_UNSPECIFIED: Assertion.AssertionType
    ASSERTION_TYPE_LLM: Assertion.AssertionType
    ASSERTION_TYPE_CODE: Assertion.AssertionType
    ASSERTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    LLM_ASSERTION_FIELD_NUMBER: _ClassVar[int]
    CODE_ASSERTION_FIELD_NUMBER: _ClassVar[int]
    METRIC_NAME_FIELD_NUMBER: _ClassVar[int]
    assertion_type: Assertion.AssertionType
    llm_assertion: LLMAssertion
    code_assertion: CodeAssertion
    metric_name: str
    def __init__(self, assertion_type: _Optional[_Union[Assertion.AssertionType, str]] = ..., llm_assertion: _Optional[_Union[LLMAssertion, _Mapping]] = ..., code_assertion: _Optional[_Union[CodeAssertion, _Mapping]] = ..., metric_name: _Optional[str] = ...) -> None: ...

class LLMAssertion(_message.Message):
    __slots__ = ("llm_evaluator_prompt", "providers", "prompts", "evaluate_options")
    LLM_EVALUATOR_PROMPT_FIELD_NUMBER: _ClassVar[int]
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    PROMPTS_FIELD_NUMBER: _ClassVar[int]
    EVALUATE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    llm_evaluator_prompt: str
    providers: _containers.RepeatedCompositeFieldContainer[Provider]
    prompts: _containers.RepeatedScalarFieldContainer[str]
    evaluate_options: EvaluateOptions
    def __init__(self, llm_evaluator_prompt: _Optional[str] = ..., providers: _Optional[_Iterable[_Union[Provider, _Mapping]]] = ..., prompts: _Optional[_Iterable[str]] = ..., evaluate_options: _Optional[_Union[EvaluateOptions, _Mapping]] = ...) -> None: ...

class CodeAssertion(_message.Message):
    __slots__ = ("language", "code", "expected_output", "options")
    class ExecutionOptions(_message.Message):
        __slots__ = ("timeout_ms", "memory_limit_mb", "env_vars")
        class EnvVarsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        TIMEOUT_MS_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_MB_FIELD_NUMBER: _ClassVar[int]
        ENV_VARS_FIELD_NUMBER: _ClassVar[int]
        timeout_ms: int
        memory_limit_mb: int
        env_vars: _containers.ScalarMap[str, str]
        def __init__(self, timeout_ms: _Optional[int] = ..., memory_limit_mb: _Optional[int] = ..., env_vars: _Optional[_Mapping[str, str]] = ...) -> None: ...
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_OUTPUT_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    language: str
    code: str
    expected_output: str
    options: CodeAssertion.ExecutionOptions
    def __init__(self, language: _Optional[str] = ..., code: _Optional[str] = ..., expected_output: _Optional[str] = ..., options: _Optional[_Union[CodeAssertion.ExecutionOptions, _Mapping]] = ...) -> None: ...

class Provider(_message.Message):
    __slots__ = ("id", "config", "label")
    class ConfigEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    config: _containers.ScalarMap[str, str]
    label: str
    def __init__(self, id: _Optional[str] = ..., config: _Optional[_Mapping[str, str]] = ..., label: _Optional[str] = ...) -> None: ...

class EvaluateOptions(_message.Message):
    __slots__ = ("max_concurrency", "repeat", "delay")
    MAX_CONCURRENCY_FIELD_NUMBER: _ClassVar[int]
    REPEAT_FIELD_NUMBER: _ClassVar[int]
    DELAY_FIELD_NUMBER: _ClassVar[int]
    max_concurrency: int
    repeat: int
    delay: int
    def __init__(self, max_concurrency: _Optional[int] = ..., repeat: _Optional[int] = ..., delay: _Optional[int] = ...) -> None: ...

class GetEvaluationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateEvaluationRequest(_message.Message):
    __slots__ = ("parent", "evaluation", "evaluation_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    evaluation: Evaluation
    evaluation_id: str
    def __init__(self, parent: _Optional[str] = ..., evaluation: _Optional[_Union[Evaluation, _Mapping]] = ..., evaluation_id: _Optional[str] = ...) -> None: ...

class ListEvaluationsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListEvaluationsResponse(_message.Message):
    __slots__ = ("evaluations", "next_page_token", "total_size")
    EVALUATIONS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    evaluations: _containers.RepeatedCompositeFieldContainer[Evaluation]
    next_page_token: str
    total_size: int
    def __init__(self, evaluations: _Optional[_Iterable[_Union[Evaluation, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateEvaluationRequest(_message.Message):
    __slots__ = ("name", "evaluation", "update_mask")
    NAME_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    name: str
    evaluation: Evaluation
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, name: _Optional[str] = ..., evaluation: _Optional[_Union[Evaluation, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteEvaluationRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class TestEvaluationRequest(_message.Message):
    __slots__ = ("parent", "evaluation", "sample_data")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_DATA_FIELD_NUMBER: _ClassVar[int]
    parent: str
    evaluation: Evaluation
    sample_data: str
    def __init__(self, parent: _Optional[str] = ..., evaluation: _Optional[_Union[Evaluation, _Mapping]] = ..., sample_data: _Optional[str] = ...) -> None: ...

class ValidateAssertionsRequest(_message.Message):
    __slots__ = ("parent", "assertions")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    ASSERTIONS_FIELD_NUMBER: _ClassVar[int]
    parent: str
    assertions: _containers.RepeatedCompositeFieldContainer[Assertion]
    def __init__(self, parent: _Optional[str] = ..., assertions: _Optional[_Iterable[_Union[Assertion, _Mapping]]] = ...) -> None: ...

class ValidateAssertionsResponse(_message.Message):
    __slots__ = ("status", "metric_to_errors")
    class MetricToErrorsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ValidateAssertionsResponse.ValidateAssertionError
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ValidateAssertionsResponse.ValidateAssertionError, _Mapping]] = ...) -> None: ...
    class ValidateAssertionError(_message.Message):
        __slots__ = ("error_messages",)
        ERROR_MESSAGES_FIELD_NUMBER: _ClassVar[int]
        error_messages: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, error_messages: _Optional[_Iterable[str]] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    METRIC_TO_ERRORS_FIELD_NUMBER: _ClassVar[int]
    status: str
    metric_to_errors: _containers.MessageMap[str, ValidateAssertionsResponse.ValidateAssertionError]
    def __init__(self, status: _Optional[str] = ..., metric_to_errors: _Optional[_Mapping[str, ValidateAssertionsResponse.ValidateAssertionError]] = ...) -> None: ...

class PreviewEvaluationRequest(_message.Message):
    __slots__ = ("name", "sample_data", "max_samples")
    NAME_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_DATA_FIELD_NUMBER: _ClassVar[int]
    MAX_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    name: str
    sample_data: str
    max_samples: int
    def __init__(self, name: _Optional[str] = ..., sample_data: _Optional[str] = ..., max_samples: _Optional[int] = ...) -> None: ...

class PreviewEvaluationResult(_message.Message):
    __slots__ = ("success", "reason", "score", "messages", "metrics")
    class MetricsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: float
        def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    reason: str
    score: float
    messages: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    metrics: _containers.ScalarMap[str, float]
    def __init__(self, success: bool = ..., reason: _Optional[str] = ..., score: _Optional[float] = ..., messages: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ..., metrics: _Optional[_Mapping[str, float]] = ...) -> None: ...

class PreviewEvaluationResponse(_message.Message):
    __slots__ = ("results", "total_samples", "total_runtime_ms")
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    TOTAL_RUNTIME_MS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[PreviewEvaluationResult]
    total_samples: int
    total_runtime_ms: int
    def __init__(self, results: _Optional[_Iterable[_Union[PreviewEvaluationResult, _Mapping]]] = ..., total_samples: _Optional[int] = ..., total_runtime_ms: _Optional[int] = ...) -> None: ...



import httpx
import asyncio
import os

from urllib.parse import urlparse
from typing import List, Optional, Union

from .audio_api import (
    AlignmentRequest,
    TranscriptionRequest,
    TranslationRequest,
    TranscriptionResponse,
    TranscriptionVerboseResponse,
)
from .api_client import FireworksClient


UrlPath = str


class AudioInference(FireworksClient):
    """
    Main client class for the Fireworks Audio Generation APIs.
    """

    def __init__(
        self,
        model: str = "whisper-v3",
        vad_model: str = "silero",
        alignment_model: str = "tdnn_ffn",
        diarization_model: str = "pyannote",
        request_timeout=600,
        api_key: Optional[str] = None,
        base_url: Optional[str] = None,
        **kwargs,
    ) -> None:
        super().__init__(request_timeout, api_key=api_key, base_url=base_url, **kwargs)
        self.model = model
        self.vad_model = vad_model
        self.alignment_model = alignment_model
        self.diarization_model = diarization_model

    @staticmethod
    def _audio_to_bytes(audio: Union[str, os.PathLike, UrlPath, bytes]) -> bytes:
        def is_url(path: str) -> bool:
            try:
                parsed = urlparse(path)
                return bool(parsed.scheme) and bool(parsed.netloc)
            except:
                return False

        if is_url(audio):
            return audio.encode("utf-8")
        elif isinstance(audio, (str, os.PathLike)):
            with open(audio, "rb") as f:
                audio = f.read()
        return audio

    def transcribe(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        model: str = None,
        vad_model: str = None,
        alignment_model: str = None,
        diarization_model: str = None,
        skip_vad: bool = None,
        prompt: Optional[str] = None,
        response_format: Optional[str] = None,
        temperature: Optional[Union[float, List[float]]] = None,
        preprocessing: Optional[str] = None,
        max_clip_len: Optional[float] = None,
        language: Optional[str] = None,
        timestamp_granularities: Optional[List[str]] = None,
        diarize: Optional[str] = None,
        min_speakers: Optional[int] = None,
        max_speakers: Optional[int] = None,
    ) -> TranscriptionResponse:
        """
        Transcribe an audio into text using ASR (audio speech recognition).
        See the OpenAPI spec (https://docs.fireworks.ai/api-reference/audio-transcriptions)
        for the most up-to-date description of the supported parameters

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to transcribe.
        - model (str, optional): The ASR model name to call. If not present, defaults to `self.model` on the AudioInference object.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - diarization_model (str, optional): The diarization model name to call. If not present, defaults to `self.diarization_model` on the AudioInference object.
        - skip_vad (bool, optional): Whether to skip VAD. VAD can be skipped for audios shorter than 30 seconds only. If not present, defaults to "False".
        - prompt (str, optional): The input prompt with which to prime transcription. This can be used, for example, to continue a prior transcription given new audio data.
        - response_format (str): The format in which to return the response. Can be one of "json", "text", "srt", "verbose_json", or "vtt". If not present, defaults to "json".
        - temperature (Union[float, List[float]], optional): Sampling temperature to use when decoding text tokens during transcription. Alternatively, a list of temperatures to enable fallback decoding. If not present, defaults to "0.0".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".
        - max_clip_len (float, optional): The desired maximum length of audio segment.
        - language (str, optional): The target languages for transcription. The set of supported target languages can be found at https://tinyurl.com/bdz3y63b.
        - timestamp_granularities (List[str], optional): The timestamp granularities to populate for this transcription. `response_format` must be set "verbose_json" to use timestamp granularities. Either or both of these options are supported: "word", or "segment". If not present, defaults to "segment".
        - diarize (str, optional): Whether to get speaker diarization for the audio. Can be one of "true", or "false". `response_format` must be set "verbose_json" and `timestamp_granularities` must include "word" to use diarization. If not present, defaults to "false".
        - min_speakers (int, optional): The minimum number of expected speakers for diarization. `diarize` must be set "true" to use `min_speakers`.
        - max_speakers (int, optional): The maximum number of expected speakers for diarization. `diarize` must be set "true" to use `max_speakers`.

        Returns:
        TranscriptionResponse: An object with transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        return asyncio.run(
            self.transcribe_async(
                audio,
                model,
                vad_model,
                alignment_model,
                diarization_model,
                skip_vad,
                prompt,
                response_format,
                temperature,
                preprocessing,
                max_clip_len,
                language,
                timestamp_granularities,
                diarize,
                min_speakers,
                max_speakers,
            )
        )

    async def transcribe_async(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        model: str = None,
        vad_model: str = None,
        alignment_model: str = None,
        diarization_model: str = None,
        skip_vad: bool = None,
        prompt: Optional[str] = None,
        response_format: Optional[str] = None,
        temperature: Optional[Union[float, List[float]]] = None,
        preprocessing: Optional[str] = None,
        max_clip_len: Optional[float] = None,
        language: Optional[str] = None,
        timestamp_granularities: Optional[List[str]] = None,
        diarize: Optional[str] = None,
        min_speakers: Optional[int] = None,
        max_speakers: Optional[int] = None,
    ) -> Union[TranscriptionResponse, TranscriptionVerboseResponse, str]:
        """
        Transcribe an audio into text using ASR (audio speech recognition).
        See the OpenAPI spec (https://docs.fireworks.ai/api-reference/audio-transcriptions)
        for the most up-to-date description of the supported parameters

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to transcribe.
        - model (str, optional): The ASR model name to call. If not present, defaults to `self.model` on the AudioInference object.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - diarization_model (str, optional): The diarization model name to call. If not present, defaults to `self.diarization_model` on the AudioInference object.
        - skip_vad (bool, optional): Whether to skip VAD. VAD can be skipped for audios shorter than 30 seconds only. If not present, defaults to "False".
        - prompt (str, optional): The input prompt with which to prime transcription. This can be used, for example, to continue a prior transcription given new audio data.
        - response_format (str): The format in which to return the response. Can be one of "json", "text", "srt", "verbose_json", or "vtt". If not present, defaults to "json".
        - temperature (Union[float, List[float]], optional): Sampling temperature to use when decoding text tokens during transcription. Alternatively, a list of temperatures to enable fallback decoding. If not present, defaults to "0.0".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".
        - max_clip_len (float, optional): The desired maximum length of audio segment.
        - language (str, optional): The target languages for transcription. The set of supported target languages can be found at https://tinyurl.com/bdz3y63b.
        - timestamp_granularities (List[str], optional): The timestamp granularities to populate for this transcription. `response_format` must be set "verbose_json" to use timestamp granularities. Either or both of these options are supported: "word", or "segment". If not present, defaults to "segment".
        - diarize (str, optional): Whether to get speaker diarization for the audio. Can be one of "true", or "false". `response_format` must be set "verbose_json" and `timestamp_granularities` must include "word" to use diarization. If not present, defaults to "false".
        - min_speakers (int, optional): The minimum number of expected speakers for diarization. `diarize` must be set "true" to use `min_speakers`.
        - max_speakers (int, optional): The maximum number of expected speakers for diarization. `diarize` must be set "true" to use `max_speakers`.

        Returns:
        TranscriptionResponse: An object with transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        request = TranscriptionRequest(
            model=model or self.model,
            vad_model=vad_model or self.vad_model,
            alignment_model=alignment_model or self.alignment_model,
            diarization_model=diarization_model or self.diarization_model,
            skip_vad=skip_vad,
            prompt=prompt,
            response_format=response_format,
            temperature=temperature,
            preprocessing=preprocessing,
            max_clip_len=max_clip_len,
            language=language,
            timestamp_granularities=timestamp_granularities,
            diarize=diarize,
            min_speakers=min_speakers,
            max_speakers=max_speakers,
        )
        data = {
            **request.to_multipart(),
        }
        files = {
            "file": self._audio_to_bytes(audio),
        }
        headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Accept": "application/json",
        }
        async with httpx.AsyncClient(
            headers=headers,
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            endpoint_base_uri = f"{self.base_url}/v1/audio/transcriptions"
            response = await client.post(endpoint_base_uri, data=data, files=files)
            self._error_handling(response)

            if response_format in [None, "json"]:
                return TranscriptionResponse(**response.json())
            elif response_format == "verbose_json":
                return TranscriptionVerboseResponse(**response.json())
            else:
                return response.text

    def translate(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        model: str = None,
        vad_model: str = None,
        alignment_model: str = None,
        skip_vad: bool = None,
        prompt: Optional[str] = None,
        response_format: Optional[str] = None,
        temperature: Optional[Union[float, List[float]]] = None,
        preprocessing: Optional[str] = None,
        max_clip_len: Optional[float] = None,
        timestamp_granularities: Optional[List[str]] = None,
    ) -> TranscriptionResponse:
        """
        Translate an audio into english text using ASR (audio speech recognition).
        See the OpenAPI spec (https://docs.fireworks.ai/api-reference/audio-translations)
        for the most up-to-date description of the supported parameters

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to translate.
        - model (str, optional): The ASR model name to call. If not present, defaults to `self.model` on the AudioInference object.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - skip_vad (bool, optional): Whether to skip VAD. VAD can be skipped for audios shorter than 30 seconds only. If not present, defaults to "False".
        - prompt (str, optional): The input prompt with which to prime transcription. This can be used, for example, to continue a prior transcription given new audio data.
        - response_format (str): The format in which to return the response. Can be one of "json", "text", "srt", "verbose_json", or "vtt". If not present, defaults to "json".
        - temperature (Union[float, List[float]], optional): Sampling temperature to use when decoding text tokens during transcription. Alternatively, a list of temperatures to enable fallback decoding. If not present, defaults to "0.0".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".
        - max_clip_len (float, optional): The desired maximum length of audio segment.
        - timestamp_granularities (List[str], optional): The timestamp granularities to populate for this transcription. `response_format` must be set "verbose_json" to use timestamp granularities. Either or both of these options are supported: "word", or "segment". If not present, defaults to "segment".

        Returns:
        TranscriptionResponse: An object with english transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        return asyncio.run(
            self.translate_async(
                audio,
                model,
                vad_model,
                alignment_model,
                skip_vad,
                prompt,
                response_format,
                temperature,
                preprocessing,
                max_clip_len,
                timestamp_granularities,
            )
        )

    async def translate_async(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        model: str = None,
        vad_model: str = None,
        alignment_model: str = None,
        skip_vad: bool = None,
        prompt: Optional[str] = None,
        response_format: Optional[str] = None,
        temperature: Optional[Union[float, List[float]]] = None,
        preprocessing: Optional[str] = None,
        max_clip_len: Optional[float] = None,
        timestamp_granularities: Optional[List[str]] = None,
    ) -> Union[TranscriptionResponse, TranscriptionVerboseResponse, str]:
        """
        Translate an audio into english text using ASR (audio speech recognition).
        See the OpenAPI spec (https://docs.fireworks.ai/api-reference/audio-translations)
        for the most up-to-date description of the supported parameters

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to translate.
        - model (str, optional): The ASR model name to call. If not present, defaults to `self.model` on the AudioInference object.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - skip_vad (bool, optional): Whether to skip VAD. VAD can be skipped for audios shorter than 30 seconds only. If not present, defaults to "False".
        - prompt (str, optional): The input prompt with which to prime transcription. This can be used, for example, to continue a prior transcription given new audio data.
        - response_format (str): The format in which to return the response. Can be one of "json", "text", "srt", "verbose_json", or "vtt". If not present, defaults to "json".
        - temperature (Union[float, List[float]], optional): Sampling temperature to use when decoding text tokens during transcription. Alternatively, a list of temperatures to enable fallback decoding. If not present, defaults to "0.0".
        - timestamp_granularities (List[str]): The timestamp granularities to populate for this transcription. `response_format` must be set "verbose_json" to use timestamp granularities. Either or both of these options are supported: "word", or "segment". If not present, defaults to "segment".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".
        - max_clip_len (float, optional): The desired maximum length of audio segment.
        - timestamp_granularities (List[str], optional): The timestamp granularities to populate for this transcription. `response_format` must be set "verbose_json" to use timestamp granularities. Either or both of these options are supported: "word", or "segment". If not present, defaults to "segment".

        Returns:
        TranscriptionResponse: An object with english transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        request = TranslationRequest(
            model=model or self.model,
            vad_model=vad_model or self.vad_model,
            alignment_model=alignment_model or self.alignment_model,
            skip_vad=skip_vad,
            prompt=prompt,
            response_format=response_format,
            temperature=temperature,
            preprocessing=preprocessing,
            max_clip_len=max_clip_len,
            timestamp_granularities=timestamp_granularities,
        )
        data = {
            **request.to_multipart(),
        }
        files = {
            "file": self._audio_to_bytes(audio),
        }
        headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Accept": "application/json",
        }
        async with httpx.AsyncClient(
            headers=headers,
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            endpoint_base_uri = f"{self.base_url}/v1/audio/translations"
            response = await client.post(endpoint_base_uri, data=data, files=files)
            self._error_handling(response)

            if response_format in [None, "json"]:
                return TranscriptionResponse(**response.json())
            elif response_format == "verbose_json":
                return TranscriptionVerboseResponse(**response.json())
            else:
                return response.text

    def align(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        text: str,
        vad_model: str = None,
        alignment_model: str = None,
        response_format: Optional[str] = None,
        preprocessing: Optional[str] = None,
    ) -> Union[TranscriptionResponse, TranscriptionVerboseResponse, str]:
        """
        Align an audio into text using ASR (audio speech recognition).

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to align.
        - text (str): The text to align to the audio.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - response_format (str): The format in which to return the response. Can be one of  "srt", "verbose_json", or "vtt". If not present, defaults to "verbose_json".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".

        Returns:
        TranscriptionResponse: An object with transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        return asyncio.run(
            self.align_async(
                audio,
                text,
                vad_model,
                alignment_model,
                response_format,
                preprocessing,
            )
        )

    async def align_async(
        self,
        audio: Union[str, os.PathLike, bytes, UrlPath],
        text: str,
        vad_model: str = None,
        alignment_model: str = None,
        response_format: Optional[str] = None,
        preprocessing: Optional[str] = None,
    ) -> Union[TranscriptionResponse, TranscriptionVerboseResponse, str]:
        """
        Align an audio into text using ASR (audio speech recognition).

        Parameters:
        - audio (Union[str, os.PathLike, bytes, UrlPath]): An audio to align.
        - text (str): The text to align to the audio.
        - vad_model (str, optional): The VAD model name to call. If not present, defaults to `self.vad_model` on the AudioInference object.
        - alignment_model (str, optional): The alignment model name to call. If not present, defaults to `self.alignment_model` on the AudioInference object.
        - response_format (str): The format in which to return the response. Can be one of  "srt", "verbose_json", or "vtt". If not present, defaults to "verbose_json".
        - preprocessing (str, optional): The preprocessing to apply. Can be one of "none", "dynamic", "soft_dynamic", "bass_dynamic". If not present, defaults to "none".

        Returns:
        TranscriptionResponse: An object with transcription.

        Raises:
        RuntimeError: If there is an error in the audio transcription process.
        """
        request = AlignmentRequest(
            text=text,
            vad_model=vad_model or self.vad_model,
            alignment_model=alignment_model or self.alignment_model,
            response_format=response_format,
            preprocessing=preprocessing,
        )
        data = {
            **request.to_multipart(),
        }
        files = {
            "file": self._audio_to_bytes(audio),
        }
        headers = {
            "Authorization": f"Bearer {self.api_key}",
            "Accept": "application/json",
        }
        async with httpx.AsyncClient(
            headers=headers,
            timeout=self.request_timeout,
            **self.client_kwargs,
        ) as client:
            endpoint_base_uri = f"{self.base_url}/v1/audio/alignments"
            response = await client.post(endpoint_base_uri, data=data, files=files)
            self._error_handling(response)

            if response_format in [None, "verbose_json"]:
                return TranscriptionVerboseResponse(**response.json())
            else:
                return response.text


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/environment.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/environment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/environment.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x06\n\x0b\x45nvironment\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x06 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x30\n\x05state\x18\n \x01(\x0e\x32\x1a.gateway.Environment.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x39\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x05\xe2\x41\x02\x03\x05\x12\x1d\n\x0e\x62\x61se_image_ref\x18\x07 \x01(\tB\x05\xe2\x41\x02\x01\x05\x12\x18\n\timage_ref\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x12snapshot_image_ref\x18\x08 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x0e\n\x06shared\x18\x0c \x01(\x08\x12@\n\x0b\x61nnotations\x18\t \x03(\x0b\x32%.gateway.Environment.AnnotationsEntryB\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\x12\x0e\n\nCONNECTING\x10\x03\x12\r\n\tCONNECTED\x10\x04\x12\x11\n\rDISCONNECTING\x10\x05\x12\x10\n\x0cRECONNECTING\x10\x07\x12\x0c\n\x08\x44\x45LETING\x10\x06:\x94\x01\xea\x41\x81\x01\n\x1c\x61pi.fireworks.ai/Environment\x12\x46\x61\x63\x63ounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}*\x0c\x65nvironments2\x0b\x65nvironment\x82\xf1\x04\x0b\n\x07\x43luster\x18\x01\"\x98\x01\n\x15\x45nvironmentConnection\x12\x1a\n\x0cnode_pool_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tnum_ranks\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x12\n\x04role\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01\x12\x13\n\x04zone\x18\x05 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x11use_local_storage\x18\x07 \x01(\x08\x42\x06\x18\x01\xe2\x41\x01\x01\"\x7f\n\x18\x43reateEnvironmentRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12/\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x14.gateway.EnvironmentB\x04\xe2\x41\x01\x02\x12\x1c\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\"+\n\x15GetEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"\x90\x01\n\x17ListEnvironmentsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"s\n\x18ListEnvironmentsResponse\x12*\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x14.gateway.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\x82\x01\n\x18UpdateEnvironmentRequest\x12/\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x14.gateway.EnvironmentB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\".\n\x18\x44\x65leteEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"K\n\x1e\x42\x61tchDeleteEnvironmentsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05names\x18\x02 \x03(\tB\x04\xe2\x41\x01\x02\"\x87\x01\n\x19\x43onnectEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x38\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x04\xe2\x41\x01\x02\x12\x1c\n\x0evscode_version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"f\n\x1c\x44isconnectEnvironmentRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x13\n\x05\x66orce\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1d\n\x0freset_snapshots\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.environment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENT'].fields_by_name['name']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT'].fields_by_name['create_time']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['created_by']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['state']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['status']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['connection']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['connection']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['base_image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['base_image_ref']._serialized_options = b'\342A\002\001\005'
  _globals['_ENVIRONMENT'].fields_by_name['image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['image_ref']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['snapshot_image_ref']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['snapshot_image_ref']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENT'].fields_by_name['annotations']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['annotations']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT'].fields_by_name['update_time']._loaded_options = None
  _globals['_ENVIRONMENT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ENVIRONMENT']._loaded_options = None
  _globals['_ENVIRONMENT']._serialized_options = b'\352A\201\001\n\034api.fireworks.ai/Environment\022Faccounts/{AccountId}/clusters/{ClusterId}/environments/{EnvironmentId}*\014environments2\013environment\202\361\004\013\n\007Cluster\030\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['node_pool_id']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['node_pool_id']._serialized_options = b'\342A\001\002'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['num_ranks']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['num_ranks']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['role']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['role']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['zone']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['zone']._serialized_options = b'\342A\002\003\005'
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['use_local_storage']._loaded_options = None
  _globals['_ENVIRONMENTCONNECTION'].fields_by_name['use_local_storage']._serialized_options = b'\030\001\342A\001\001'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_CREATEENVIRONMENTREQUEST'].fields_by_name['environment_id']._serialized_options = b'\342A\001\002'
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['environment']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEENVIRONMENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['names']._loaded_options = None
  _globals['_BATCHDELETEENVIRONMENTSREQUEST'].fields_by_name['names']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['connection']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['vscode_version']._loaded_options = None
  _globals['_CONNECTENVIRONMENTREQUEST'].fields_by_name['vscode_version']._serialized_options = b'\342A\001\001'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['force']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['force']._serialized_options = b'\342A\001\001'
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['reset_snapshots']._loaded_options = None
  _globals['_DISCONNECTENVIRONMENTREQUEST'].fields_by_name['reset_snapshots']._serialized_options = b'\342A\001\001'
  _globals['_ENVIRONMENT']._serialized_start=211
  _globals['_ENVIRONMENT']._serialized_end=1084
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_start=736
  _globals['_ENVIRONMENT_ANNOTATIONSENTRY']._serialized_end=786
  _globals['_ENVIRONMENT_STATE']._serialized_start=789
  _globals['_ENVIRONMENT_STATE']._serialized_end=933
  _globals['_ENVIRONMENTCONNECTION']._serialized_start=1087
  _globals['_ENVIRONMENTCONNECTION']._serialized_end=1239
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_start=1241
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_end=1368
  _globals['_GETENVIRONMENTREQUEST']._serialized_start=1370
  _globals['_GETENVIRONMENTREQUEST']._serialized_end=1413
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=1416
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=1560
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_start=1562
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_end=1677
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_start=1680
  _globals['_UPDATEENVIRONMENTREQUEST']._serialized_end=1810
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_start=1812
  _globals['_DELETEENVIRONMENTREQUEST']._serialized_end=1858
  _globals['_BATCHDELETEENVIRONMENTSREQUEST']._serialized_start=1860
  _globals['_BATCHDELETEENVIRONMENTSREQUEST']._serialized_end=1935
  _globals['_CONNECTENVIRONMENTREQUEST']._serialized_start=1938
  _globals['_CONNECTENVIRONMENTREQUEST']._serialized_end=2073
  _globals['_DISCONNECTENVIRONMENTREQUEST']._serialized_start=2075
  _globals['_DISCONNECTENVIRONMENTREQUEST']._serialized_end=2177
# @@protoc_insertion_point(module_scope)
